# Tricircleclient

Python bindings to the OpenStack Tricircle API

This is a client for OpenStack Tricircle API providing a Python API (using the
**tricircleclient** module) and a Command Line Interface (installed as the
**tricircle** command). Each implements the entire OpenStack Tricircle API.

* Free software: Apache license
* [Documentation](https://docs.openstack.org/python-tricircleclient/latest/)
* [Source](http://git.openstack.org/cgit/openstack/python-tricircleclient)
* [Bugs](http://bugs.launchpad.net/python-tricircleclient)
